# The Reflex Icon Library

The Reflex Icon Library (RIL) is your one-stop icon shop for [Reflex](https://reflex.dev) projects.
It includes the icon libraries of [Font Awesome](https://fontawesome.com), [Simple Icons](https://simpleicons.org),
Google's [Material Symbols](https://fonts.google.com/icons),
GitHub's [Octicons](https://primer.style/octicons), [Phosphor](https://phosphoricons.com/),
and [Bootstrap Icons](https://icons.getbootstrap.com/), packaging over 12,000 icons in total. Subscribers to 
[Font Awesome Pro](https://ril.celsiusnarhwal.dev/fontawesome/pro) can also enjoy the over 25,000 additional icons unlocked
by the subscription as well as [full support for Kits](https://ril.celsiusnarhwal.dev/fontawesome/pro#using-a-kit).

```shell
pip install reflex-icon-library
```

For usage instructions, see [the documentation](https://ril.celsiusnarhwal.dev).